#
# spec file for package plasma-browser-integration
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define kf5_version 5.42.0
%bcond_with browser_extension
%bcond_without lang
Name:           plasma-browser-integration
Version:        5.15.4
Release:        lp150.2.3.1
Summary:        Helper for the KDE Plasma Browser Integration
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Utilities
Url:            https://cgit.kde.org/plasma-browser-integration.git
Source:         https://download.kde.org/stable/plasma/%{version}/plasma-browser-integration-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/plasma/%{version}/plasma-browser-integration-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{kf5_version}
BuildRequires:  cmake(KF5Activities) >= %{kf5_version}
BuildRequires:  cmake(KF5DBusAddons) >= %{kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{kf5_version}
BuildRequires:  cmake(KF5Notifications) >= %{kf5_version}
BuildRequires:  cmake(KF5Runner) >= %{kf5_version}
BuildRequires:  cmake(KF5WindowSystem) >= %{kf5_version}
BuildRequires:  cmake(Qt5Core) >= 5.9.0
BuildRequires:  cmake(Qt5DBus) >= 5.9.0
BuildRequires:  cmake(Qt5Gui) >= 5.9.0
%if 0%{?suse_version} < 1330
# It does not build with the default compiler (GCC 4.8) on Leap 42.x
BuildRequires:  gcc7-c++
%endif
Recommends:     %{name}-lang

%description
This package contains a helper binary necessary for the WebExtension to
work.

%package extension
Summary:        WebExtension for KDE Plamsa Browser Integration
Group:          Productivity/Networking/Web/Utilities
Requires:       %{name} = %{version}

%description extension
This package contains a WebExtension to integrate the browser better into
KDE Plasma.

%lang_package

%prep
%setup -q

%build
%if 0%{?suse_version} < 1330
	# It does not build with the default compiler (GCC 4.8) on Leap 42.x
	export CC=gcc-7
	export CXX=g++-7
%endif

%if %{with browser_extension}
%cmake_kf5 -d build -- -DINSTALL_CHROME_MANIFEST=1
%else
%cmake_kf5 -d build -- -DINSTALL_CHROME_MANIFEST=0
%endif

%make_jobs

%install
%kf5_makeinstall -C build
if [ "%{_libdir}" != "%{_libexecdir}" ]; then
	# Move mozilla native messaging file to correct location
	mv %{buildroot}%{_libexecdir}/mozilla %{buildroot}%{_libdir}
fi
  %if %{with lang}
    %find_lang %{name} --all-name
  %endif

%files
%license COPYING*
%dir %{_kf5_plugindir}/kf5
%dir %{_kf5_plugindir}/kf5/kded
%dir %{_libdir}/mozilla
%dir %{_sysconfdir}/chromium
%dir %{_sysconfdir}/opt/chrome
%{_kf5_bindir}/plasma-browser-integration-host
%{_kf5_plugindir}/kf5/kded/browserintegrationreminder.so
%{_kf5_servicesdir}/plasma-runner-browsertabs.desktop
%{_libdir}/mozilla/native-messaging-hosts
%{_libqt5_plugindir}/krunner_browsertabs.so
%{_sysconfdir}/chromium/native-messaging-hosts
%{_sysconfdir}/opt/chrome/native-messaging-hosts

%if %{with browser_extension}
%files extension
%license COPYING*
%dir %{_datadir}/chromium
%dir %{_datadir}/chromium/extensions
%dir %{_datadir}/google-chrome
%dir %{_datadir}/google-chrome/extensions
%{_datadir}/chromium/extensions/cimiefiiaegbelhefglklhhakcgmhkai.json
%{_datadir}/google-chrome/extensions/cimiefiiaegbelhefglklhhakcgmhkai.json
%endif

%if %{with lang}
%files lang -f %{name}.lang
%license COPYING*
%endif

%changelog
* Thu Apr 25 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Don't supplement browsers (only for Leap 15.0)
* Thu Apr 25 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Fix kf5_version requirement
* Tue Apr  2 2019 fabian@ritter-vogt.de
- Update to 5.15.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.4.php
- Changes since 5.15.3:
  * Update description before processing job state or error
  * [Host] Add Message.sh
* Tue Mar 12 2019 fabian@ritter-vogt.de
- Update to 5.15.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.3.php
- No code changes since 5.15.2
* Tue Feb 26 2019 fabian@ritter-vogt.de
- Update to 5.15.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.2.php
- No code changes since 5.15.1
* Tue Feb 19 2019 fabian@ritter-vogt.de
- Update to 5.15.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.1.php
- No code changes since 5.15.0
* Thu Feb  7 2019 fabian@ritter-vogt.de
- Update to 5.15.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.0.php
- No code changes since 5.14.90
* Thu Jan 17 2019 fabian@ritter-vogt.de
- Update to 5.14.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.90.php
- Changes since 5.14.5:
  * Install message handler after QApplication (kde#400906)
  * Make media session property setter more resilient (kde#401636)
  * Bump manifest version
  * Include Breeze scrollbar CSS inline
  * Also catch new Audio() elements (kde#398261)
  * Connect to contextMenu clicked callback only once
  * Update about KDE text
  * Recreate interrupted download when it is resumed (kde#401038)
  * Send all active downloads on load
  * Fix removing KDE Connect device entry
  * Sort keys in json encoder
  * Bump manifest version
  * Wait for duration to be known before registering player
  * Bump manifest version
  * Make it compiles with KDEFrameworkCompilerSettings
* Tue Jan  8 2019 fabian@ritter-vogt.de
- Update to 5.14.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.5.php
- Changes since 5.14.4:
  * Only cancel job when an "error" is set and ignore "interrupted" (kde#385530)
* Wed Nov 28 2018 fabian@ritter-vogt.de
- Update to 5.14.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.4.php
- Changes since 5.14.3:
  * Include actual player source in metadata
  * Listen to KDE Connect device signals
* Tue Nov  6 2018 fabian@ritter-vogt.de
- Add David Edmundson's key to plasma.keyring
- Update to 5.14.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.3.php
- No code changes since 5.14.2
* Tue Oct 23 2018 fabian@ritter-vogt.de
- Update to 5.14.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.2.php
- Changes since 5.14.1:
  * Lower Qt dependency to 5.9
* Tue Oct 16 2018 fabian@ritter-vogt.de
- Update to 5.14.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.1.php
- No code changes since 5.14.0
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.14.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.0.php
- Changes since 5.13.90:
  * Sort keys in json encoder
  * [MPris Plugin] Support Seek()
  * Add Messages.sh (kde#398595)
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Add tarball signature and keyring containing keys of release managers
  Jonathan Riddell and Bhushan Shah
* Thu Sep 13 2018 fabian@ritter-vogt.de
- Update to 5.13.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.90.php
- Too many changes to list here
* Tue Sep  4 2018 fabian@ritter-vogt.de
- Update to 5.13.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.5.php
- Changes since 5.13.4:
  * None
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Update to 5.13.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.4.php
- Changes since 5.13.3:
  * None
* Tue Jul 10 2018 fabian@ritter-vogt.de
- Update to 5.13.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.3.php
- Changes since 5.13.2:
  * Monitor document title (kde#395393)
* Tue Jun 26 2018 fabian@ritter-vogt.de
- Update to 5.13.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.2.php
- Changes since 5.13.1:
  * None
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.13.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.1.php
- Changes since 5.13.0:
  * None
* Thu Jun 14 2018 wbauer@tmo.at
- Recommend lang package
* Sun Jun 10 2018 fabian@ritter-vogt.de
- Update to 5.13.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.0.php
- Changes since 5.12.90:
  * Bump version number of extension in preparation for Plasma 5.13
  * Handle when the added node itself is audio/video
  * Don't bother loading on non-supported platforms
  * [Installation Reminder] Watch for service registration and hide
  * Respect libdir for Firefox native messaging host manifest
  * Use incognito tab icon only as a fallback
  * Filter out incognito tabs and media controls on Firefox
  * Revert "Install mozilla native messaging manifest to either /usr/lib or /usr/lib64 based on architecture"
  * Install mozilla native messaging manifest to either /usr/lib or /usr/lib64 based on architecture
  * Fix options page look on Firefox (kde#394369)
  * Handle children of added nodes as well
* Sat May 19 2018 fabian@ritter-vogt.de
- Update to 5.12.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.90.php
- Changes since 5.12.80:
  * Bump version number of extension in preparation for Plasma 5.13 beta
  * Set variable for chromium install dir
  * cmake: Don't install chrome manifest to ubuntu specific location (kde#393846)
  * Add link to Community Wiki page to About dialog
  * Remove superfluous <small> tags
  * Remove dead code and shut up
  * Implement reporting playback state via Media Sessions API
  * Observe entire DOM
  * UUID might start with a number which a variable is not allowed to
  * Also "randomize" plasmaMediaSessions global variable
  * WIP: Show SNI to install browser-side extension
  * Properly fix the native messaging host file
  * Hopefully handle messages spread across lines in .po files
  * Make "Translated by" credit work like in KAboutData
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.80git.20180502T081035~2c9d903
  * New bugfix release
  * For more details please see:
  * https://cgit.kde.org/plasma-browser-integration.git/log/?id=2c9d903dff81873bf04300290ead0c0eeafbd028
- Too many changes to list here
* Fri Dec  8 2017 fabian@ritter-vogt.de
- Separate WebExtension into -extension subpackage
- Don't build it by default (enabled in KUE)
* Fri Jul 14 2017 fabian@ritter-vogt.de
- Move firefox file from /usr/lib into /usr/lib{,64}
* Fri Apr 28 2017 fabian@ritter-vogt.de
- Initial packaging
